package com.nisum.abs.loyaltyService.controller;

import com.nisum.abs.loyaltyService.dto.LoyaltyDto;
import com.nisum.abs.loyaltyService.service.LoyaltyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping("loyalty")
public class LoyaltyController {

    @Autowired
    private LoyaltyService loyaltyService;

    @GetMapping("all")
    public Flux<LoyaltyDto> all(){
       return this.loyaltyService.getAll();
    }

    @GetMapping("{loyaltyId}")
    public Mono<ResponseEntity<LoyaltyDto>> getLoyaltyById(@PathVariable String loyaltyId){
        return this.loyaltyService.getLoyaltyById(loyaltyId)
                .map(ResponseEntity::ok)
                .defaultIfEmpty(ResponseEntity.notFound().build());
    }

    @PostMapping
    public Mono<LoyaltyDto> saveLoyalty(@RequestBody Mono<LoyaltyDto> loyaltyDto){
        return this.loyaltyService.saveLoyalty(loyaltyDto);

    }

    @PutMapping("{loyaltyId}")
    public Mono<ResponseEntity<LoyaltyDto>> updateLoyalty(@PathVariable String loyaltyId, @RequestBody Mono<LoyaltyDto> loyaltyDto){
       return  this.loyaltyService.updateLoyalty(loyaltyId, loyaltyDto)
                .map(ResponseEntity::ok)
                .defaultIfEmpty(ResponseEntity.notFound().build());
    }

    @DeleteMapping("{loyaltyId}")
    public Mono<Void> deleteLoyalty(@PathVariable  String loyaltyId){
       return this.loyaltyService.deleteLoyalty(loyaltyId);

    }

}
